==> flawz-0.2.0.tar.gz: flawz-0.2.0/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file.

## [0.2.0](https://github.com/orhun/flawz/compare/0.1.1..0.2.0) - 2024-05-24

### 🚀 Features

- Support opening the first HTTP reference in browser ([#11](https://github.com/orhun/flawz/pull/11)) ([#15](https://github.com/orhun/flawz/pull/15)) - ([e970ebc](https://github.com/orhun/flawz/commit/e970ebc84ddf3016e2507cd74bedd88873972e03))

### 📚 Documentation

- Update key bindings table - ([41dea0c](https://github.com/orhun/flawz/commit/41dea0cc623de18b833d307d618b004074fcb055))
- Add key bindings ([#20](https://github.com/orhun/flawz/pull/20)) - ([f8bcfa0](https://github.com/orhun/flawz/commit/f8bcfa023e22ac602f41f423075233fff7b3fa58))

### ⚙️ Miscellaneous Tasks

- Update macos runner - ([39d240b](https://github.com/orhun/flawz/commit/39d240b2e5cb0b86fdcbd24c142ba10f0d4a914c))

## [0.1.1](https://github.com/orhun/flawz/compare/0.1.0-rc.1..0.1.1) - 2024-05-20

### 🐛 Bug Fixes

- Remove unused terminal tick event ([#12](https://github.com/orhun/flawz/pull/12)) - ([39da120](https://github.com/orhun/flawz/commit/39da120b09602bb81ab23e42d11fc01ac7fded25))

### 📚 Documentation

- Add Homebrew install instructions ([#14](https://github.com/orhun/flawz/pull/14)) - ([3871647](https://github.com/orhun/flawz/commit/3871647308d0185635e47df3d1850cfaa67200e1))
- Link to the NetBSD package search page - ([557dfa1](https://github.com/orhun/flawz/commit/557dfa16fae3e02c5972a79bc7de6c8c028b3083))
- Add NetBSD instructions ([#10](https://github.com/orhun/flawz/pull/10)) - ([d6c817c](https://github.com/orhun/flawz/commit/d6c817c00683ef5832760f8711b1f9e0aa7cdbe6))
- Update documentation for event module - ([ec55a92](https://github.com/orhun/flawz/commit/ec55a929251621398288f1447c04a1b77770b768))

## [0.1.0-rc.1] - 2024-05-18

### 📚 Documentation

- Remove coverage badge - ([3a9425a](https://github.com/orhun/flawz/commit/3a9425aca2631bbcb9b0442922b2cf2b6d78bc99))

### ⚙️ Miscellaneous Tasks

- Update cargo-dist targets - ([d704fd9](https://github.com/orhun/flawz/commit/d704fd9c02297f7073e3d37e0deae6ce35c4dad1))

==> flawz-0.2.1.tar.gz: flawz-0.2.1/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file.

## [0.2.1](https://github.com/orhun/flawz/compare/0.2.0..0.2.1) - 2024-06-02

### 🐛 Bug Fixes

- Fix the constraint for showing CVE ids ([#24](https://github.com/orhun/flawz/pull/24)) ([#26](https://github.com/orhun/flawz/pull/26)) - ([88be940](https://github.com/orhun/flawz/commit/88be940db99e50a1d27fd6595209724921666ce9))

### 📚 Documentation

- *(readme)* Add nix instructions ([#22](https://github.com/orhun/flawz/pull/22)) - ([bfcdf1f](https://github.com/orhun/flawz/commit/bfcdf1f56c4358f805af8d63a94e3435087b2299))

## [0.2.0](https://github.com/orhun/flawz/compare/0.1.1..0.2.0) - 2024-05-24

### 🚀 Features

- Support opening the first HTTP reference in browser ([#11](https://github.com/orhun/flawz/pull/11)) ([#15](https://github.com/orhun/flawz/pull/15)) - ([e970ebc](https://github.com/orhun/flawz/commit/e970ebc84ddf3016e2507cd74bedd88873972e03))

### 📚 Documentation

- Update key bindings table - ([41dea0c](https://github.com/orhun/flawz/commit/41dea0cc623de18b833d307d618b004074fcb055))
- Add key bindings ([#20](https://github.com/orhun/flawz/pull/20)) - ([f8bcfa0](https://github.com/orhun/flawz/commit/f8bcfa023e22ac602f41f423075233fff7b3fa58))

### ⚙️ Miscellaneous Tasks

- Update macos runner - ([39d240b](https://github.com/orhun/flawz/commit/39d240b2e5cb0b86fdcbd24c142ba10f0d4a914c))

## [0.1.1](https://github.com/orhun/flawz/compare/0.1.0-rc.1..0.1.1) - 2024-05-20

### 🐛 Bug Fixes

- Remove unused terminal tick event ([#12](https://github.com/orhun/flawz/pull/12)) - ([39da120](https://github.com/orhun/flawz/commit/39da120b09602bb81ab23e42d11fc01ac7fded25))

### 📚 Documentation

- Add Homebrew install instructions ([#14](https://github.com/orhun/flawz/pull/14)) - ([3871647](https://github.com/orhun/flawz/commit/3871647308d0185635e47df3d1850cfaa67200e1))
- Link to the NetBSD package search page - ([557dfa1](https://github.com/orhun/flawz/commit/557dfa16fae3e02c5972a79bc7de6c8c028b3083))
- Add NetBSD instructions ([#10](https://github.com/orhun/flawz/pull/10)) - ([d6c817c](https://github.com/orhun/flawz/commit/d6c817c00683ef5832760f8711b1f9e0aa7cdbe6))
- Update documentation for event module - ([ec55a92](https://github.com/orhun/flawz/commit/ec55a929251621398288f1447c04a1b77770b768))

## [0.1.0-rc.1] - 2024-05-18

### 📚 Documentation

- Remove coverage badge - ([3a9425a](https://github.com/orhun/flawz/commit/3a9425aca2631bbcb9b0442922b2cf2b6d78bc99))

### ⚙️ Miscellaneous Tasks

- Update cargo-dist targets - ([d704fd9](https://github.com/orhun/flawz/commit/d704fd9c02297f7073e3d37e0deae6ce35c4dad1))
